#######################################################################################
###### This package handles the interaction with the Contivit box via Telnet ##########
#######################################################################################
package ERS_data;
our $VERSION = '0.07';

use strict;
use Net::SNMP qw(INTEGER INTEGER32 OCTET_STRING UNSIGNED32);
use MIBstuff 0.07;

#################################### init Variables ###################################


#######################################################################################
################################ Subroutines ##########################################
#######################################################################################
#new();
sub new {
	my $class = shift;
	my $ip = shift;
	my $logger = shift || 0;
	my $self = {};
	
	bless($self, $class);
	
	$self->{_IP} = $ip;
	$self->{_LOGGER} = $logger;
	$self->{'FtlName'} = [];
	$self->{'Instance'} = [];							# regInstance / readFilterInstances
	$self->{'InstanceCount'} = 0;							# regInstance / readFilterInstances
#	$self->{'Ftl_'.$instance] = {}							# regFilter / readFilter
	$self->{'OID'} = undef;								# / determineOID
	$self->{'Name'} = undef;							# / determineOID
	$self->{'Description'} = undef;							# / determineOID
	$self->{'Software'} = undef;							# / determineOID
	$self->{'Type'} = undef;							# ERS HW type
	
	return $self;
}

#######################################################################################
#DESTROY();
sub DESTROY {
	my $self = shift;
	
#	print "$_ = ".$self->{$_}."\n" foreach (keys %{$self});
}

#######################################################################################
#setValue();
sub setValue {
	my $self = shift;
	my $key = shift;
	my $value = shift;
	
	$self->{_LOGGER}->trace("[$self->{_IP}] SET key '$key' = '$value'");
	$self->{$key} = $value;
}

#######################################################################################
#getValue();
sub getValue {
	my $self = shift;
	my $key = shift;
	
	$self->{_LOGGER}->trace("[$self->{_IP}] GET query $key = '$self->{$key}'");
	
	return $self->{$key};
}

#######################################################################################
#ifTypeSupported();
# ERS switch type supported
#
sub ifTypeSupported {
	my $self = shift;
	
	if(defined($self->{'Type'})){
		$self->{_LOGGER}->trace("[$self->{_IP}] type defined => $self->{'Type'}");
		return 1;
	}else{
		$self->{_LOGGER}->trace("[$self->{_IP}] type not defined");
		return 0;
	}
}

#######################################################################################
#_prepRelease();
sub _prepRelease {
	my $softIn = shift;
	my $softOut;
	
	foreach my $digit (split(/\./, $softIn)){
		while(length($digit) < 3){
			$digit = '0'.$digit;
		}
		$softOut .= $digit;
	}
	$softOut =~ s/^0+//;
	
	return $softOut;
}

#######################################################################################
#regInstance();
sub regInstance {
	my $self = shift;
	my $value = shift;
	
	push(@{$self->{'Instance'}}, $value);
	$self->{'InstanceCount'}++;
	$self->{_LOGGER}->trace("[$self->{_IP}] register 'Instance' = $value");
}

#######################################################################################
#getTime(time hash)
sub getTime {
	my ($second, $minute, $hour, $day, $month, $year, $wday) = (localtime)[0,1,2,3,4,5,6];
	my $getTime = localtime;
	my %monthName = (
		1  => "Jan",
		2  => "Feb",
		3  => "Mar",
		4  => "Apr",
		5  => "May",
		6  => "Jun",
		7  => "Jul",
		8  => "Aug",
		9  => "Sep",
		10 => "Oct",
		11 => "Nov",
		12 => "Dec",
	);
	my %weekDayName = (
		0  => "Sun",
		1  => "Mon",
		2  => "Tue",
		3  => "Wed",
		4  => "Thu",
		5  => "Fri",
		6  => "Sat",
	);
		
	$month++;
	my $monthName = $monthName{$month};
	$year = $year + 1900;
	if ($month < 10){$month = '0'.$month;}
	if ($day < 10){$day = '0'.$day;}
	if ($hour < 10){$hour = '0'.$hour;}
	if ($minute < 10){$minute = '0'.$minute;}
	if ($second < 10){$second = '0'.$second;}

	my %sysTime = (
		all	=> $getTime,
		second 	=> $second,
		minute 	=> $minute,
		hour 	=> $hour,
		day	=> $day,
		weekDay	=> $weekDayName{$wday},
		month	=> $month,
		monthName => $monthName,
		year	=> $year,
	);
	return %sysTime
}

1;